/**
 * Driver method for lab 7
 * 
 * <P>
 * 
 * <UL>
 * <LI> Creates a primary window with two buttons.
 * <LI> Each button causes the creation of new instance of a window
 * <LI> Main thread then loops forever: asking the model to update
 * the light sensors, then (after a delay) the temperature sensor, then
 * (after a delay) this is repeated.
 * </UL>
 * <P>
 * 
 * @author Andrew H. Fagg
 * 
 */
import java.awt.GridLayout;
import javax.swing.*;
import javax.swing.JFrame;
import java.awt.event.*;
import finch.Finch;


public class lab7Driver extends JFrame {
	private JButton b1, b2;
	FinchModel model;
	
    /**
     * Sleep for a specified period of time.
     * 
     * @param i Number of milliseconds to sleep for
     */
	static public void mySleep(int i) {
    	try{
    	    Thread.sleep(i);
    	}catch(Exception e)
    	    {
    		System.out.println(e);
    	    }
        }
    
	/**
	 * Constructor.
	 * 
	 * <P>
	 * 
	 * Creates the window with the "View Light" and "View Temperature"
	 * buttons
	 * 
	 * <P>
	 * 
	 * @param model Reference to the existing model object
	 */
	public lab7Driver(FinchModel model){
		
		// Remember the reference to the model
		this.model = model;
		
		// Set up window
		this.setTitle("Command Buttons");
		this.setLocationRelativeTo(null);
		this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	
		// Set up a grid that will have 1 row (and an arbitrary number of columns)
		this.setLayout(new GridLayout(1, 0, 10, 10));
		
		// Add the buttons
		b1 = new JButton("View Light");
		
		// Action listener: create a Light Window
		b1.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e){
				createLightWindow();
			}
		});
		
		// Add this button to the JFrame
		this.add(b1);
		
		b2 = new JButton("View Temperature");
		
		// Action listener: create a Temperature Window
		b2.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e){
				createTemperatureWindow();
			}
		});
		// Add this button to the JFrame
		this.add(b2);
		
		
		// Pack all of the components (make the window just
		// the size necessary to show the two buttons)
		this.pack();
		
		// Make the window viewable
		this.setVisible(true);
		
	}
	
	/**
	 * Create a new instance of the Light Window (note that this
	 * object is persistent after this method returns)
	 *
	 */
	private void createLightWindow(){
		LightWindow w = new LightWindow(this, this.model);
	}
	
	/**
	 * Create a new instance of the Temperature Window (note that this
	 * object is persistent after this method returns)
	 *
	 */
	private void createTemperatureWindow(){
		TemperatureWindow w = new TemperatureWindow(this, this.model);
	}
	
	/**
	 * Main method
	 * <P>
	 * 
	 * @param args Are ignored
	 */
	static public void main(String[] args){
		// Reference to the Finch object
		Finch myFinch = null;
		// Comment in the next line to actually connect to the Finch
		//myFinch = new Finch();
		
		// Create the model
		FinchModel model = new FinchModel(myFinch);
		
		// Create the primary window
		lab7Driver driver = new lab7Driver(model);
		
		// Loop forever
		while(true){
			// Force the temperature to update
			model.updateTemperature();
			mySleep(1000);
			
			// Force the light sensors to update
			model.updateLight();
			mySleep(1000);
		}
	}
}
